@@ -4,39 +4,31 @@ from __future__ import annotations
 from abc import abstractmethod
 from collections.abc import Iterable
 import time
-from typing import Any, Dict, Final, List, Optional, Tuple, Type
+from typing import Any, Dict, Final, List, Optional, Type
 
 from .constants import (
-    DATA_FAN_POWER,
     DATA_FUEL_CONSUMPTION,
-    DATA_FUEL_LEVEL,
-    DATA_LOAD,
+    DATA_MIXERS,
     DATA_MODE,
-    DATA_POWER,
-    DATA_THERMOSTAT,
-    DATA_TRANSMISSION,
+    DATA_MODULES,
+    DATA_PASSWORD,
+    DATA_PRODUCT,
+    DATA_REGDATA,
+    DATA_SCHEMA,
     DATA_UNKNOWN,
     ECOMAX_ADDRESS,
     ECOSTER_ADDRESS,
 )
-from .data_types import DataType
-from .frames import Request, requests
+from .data_types import Boolean
+from .frames import Frame, Request, messages, requests, responses
 from .helpers.base_device import BaseDevice
 from .helpers.parameter import Parameter
 from .helpers.product_info import ConnectedModules, ProductInfo
 from .mixers import MixerCollection
 from .storage import FrameBucket
-from .structures import (
-    alarms,
-    device_parameters,
-    frame_versions,
-    lambda_,
-    output_flags,
-    outputs,
-    statuses,
-    temperatures,
-    thermostats,
-)
+from .stream import FrameWriter
+from .structures.device_parameters import DEVICE_PARAMETERS, PARAMETER_BOILER_CONTROL
+from .structures.frame_versions import FRAME_VERSIONS
 
 MODE_OFF: Final = 0
 MODE_FANNING: Final = 1
@@ -55,35 +47,12 @@ MODES: Final = (
     "Standby",
 )
 
-DEVICE_DATA: List[str] = [
-    DATA_FAN_POWER,
-    DATA_FUEL_CONSUMPTION,
-    DATA_FUEL_LEVEL,
-    DATA_LOAD,
-    DATA_MODE,
-    DATA_POWER,
-    DATA_THERMOSTAT,
-    DATA_TRANSMISSION,
-]
-DEVICE_DATA.extend(alarms.ALARMS)
-DEVICE_DATA.extend(frame_versions.FRAME_VERSIONS)
-DEVICE_DATA.extend(temperatures.TEMPERATURES)
-DEVICE_DATA.extend(outputs.OUTPUTS)
-DEVICE_DATA.extend(output_flags.OUTPUT_FLAGS)
-DEVICE_DATA.extend(statuses.STATUSES)
-DEVICE_DATA.extend(lambda_.LAMBDA)
-DEVICE_DATA.extend(thermostats.THERMOSTATS)
-
 
 class Device(BaseDevice):
     """Device representation.
 
     Attributes:
         bucket -- frame version info storage
-        mixers -- collection of device mixers
-        product -- device product info
-        password -- device service password
-        schema -- device regdata schema
     """
 
     def __init__(
@@ -98,39 +67,17 @@ class Device(BaseDevice):
             parameters -- editable parameters
         """
         self.bucket = FrameBucket(address=self.address, required=self.required_frames)
-        self.mixers = MixerCollection(address=self.address)
-        self.product = ProductInfo()
-        self.modules = ConnectedModules()
-        self.password = None
-        self.schema: List[Tuple[str, DataType]] = []
         super().__init__(data, parameters)
 
-    def __str__(self) -> str:
-        """Converts device instance to a string."""
-        return f"""
-Model:     {self.product.model}
-UID:       {self.product.uid}
-Password:  {self.password}
-Modules:   {self.modules}
-
-{super().__str__()}
-
-Mixers:
-{self.mixers}
-""".strip()
-
     def set_data(self, data: Dict[str, Any]) -> None:
         """Sets device data.
 
         Keyword arguments:
             data -- immutable device attributes
         """
-        for name, value in data.items():
-            if name in DEVICE_DATA:
-                self._data[name] = value
-
-        if frame_versions.FRAME_VERSIONS in data:
-            self.bucket.fill(data[frame_versions.FRAME_VERSIONS])
+        self._data = {**self._data, **data}
+        if FRAME_VERSIONS in data:
+            self.bucket.fill(data[FRAME_VERSIONS])
 
     def set_parameters(self, parameters: Dict[str, List[int]]) -> None:
         """Sets device parameters.
@@ -138,17 +85,50 @@ Mixers:
         Keyword arguments:
             parameters -- device changeable parameters
         """
-        for name, parameter in parameters.items():
-            if name in device_parameters.DEVICE_PARAMETERS:
-                self._parameters[name] = Parameter(name, *parameter)
+        self._parameters = {
+            name: Parameter(name, *parameter)
+            for name, parameter in parameters.items()
+            if name in self.editable_parameters
+        }
+
+    def handle_frame(self, frame: Frame, writer: FrameWriter) -> None:
+        """Handles received frame.
+
+        Keyword arguments:
+            frame -- received frame
+            writer -- instance of frame writer
+        """
+        if isinstance(frame, requests.ProgramVersion):
+            writer.queue(frame.response())
+
+        elif isinstance(
+            frame, (responses.UID, responses.DataSchema, messages.CurrentData)
+        ):
+            self.set_data(frame.data)
+
+    @property
+    def product(self) -> ProductInfo:
+        """Returns product info."""
+        if DATA_PRODUCT not in self._data:
+            self._data[DATA_PRODUCT] = ProductInfo()
+
+        return self._data[DATA_PRODUCT]
+
+    @property
+    def modules(self) -> ConnectedModules:
+        """Returns list of connected modules."""
+        if DATA_MODULES not in self._data:
+            self._data[DATA_MODULES] = ConnectedModules()
+
+        return self._data[DATA_MODULES]
 
     @property
     def is_on(self) -> bool:
         """Returns current state."""
-        if DATA_MODE in self._data:
-            return self._data[DATA_MODE] != MODE_OFF
+        if DATA_MODE not in self._data:
+            self._data[DATA_MODE] = MODE_OFF
 
-        return False
+        return self._data[DATA_MODE] != MODE_OFF
 
     @property
     def mode(self) -> Optional[str]:
@@ -166,14 +146,13 @@ Mixers:
         """Returns changed device parameters."""
         changes = self.queue
         changes.extend(self.bucket.queue)
-        changes.extend(self.mixers.queue)
         return changes
 
     @property
     def editable_parameters(self) -> List[str]:
         """Returns list of editable parameters."""
         parameters: List[str] = []
-        parameters.extend(device_parameters.DEVICE_PARAMETERS)
+        parameters.extend(DEVICE_PARAMETERS)
         return parameters
 
     @property
@@ -187,11 +166,13 @@ class EcoMAX(Device):
 
     Attributes:
         address -- device address
+        mixers -- collection of device mixers
         _fuel_burned -- amount of fuel burned in kilograms
         _fuel_burned_timestamp -- timestamp of burned fuel value update
     """
 
     address = ECOMAX_ADDRESS
+    mixers: Optional[MixerCollection] = None
     _fuel_burned: float = 0.0
     _fuel_burned_timestamp: float = 0.0
 
@@ -206,10 +187,20 @@ class EcoMAX(Device):
             data -- device data
             parameters -- editable parameters
         """
+        self.mixers = MixerCollection(address=self.address)
         self._fuel_burned = 0.0
         self._fuel_burned_timestamp = time.time()
         super().__init__(data, parameters)
 
+    def __str__(self) -> str:
+        """Converts device instance to a string."""
+        return f"""
+{super().__str__()}
+
+Mixers:
+{self.mixers}
+""".strip()
+
     def set_data(self, data: Dict[str, Any]) -> None:
         """Sets device data.
 
@@ -219,23 +210,65 @@ class EcoMAX(Device):
         if DATA_FUEL_CONSUMPTION in data:
             self._set_fuel_burned(data[DATA_FUEL_CONSUMPTION])
 
-        self._set_boiler_control_parameter()
+        if DATA_REGDATA in data and DATA_SCHEMA in self.data:
+            self._set_data_from_regdata(data[DATA_REGDATA])
+
+        if DATA_MODE in data:
+            self._set_boiler_control_parameter()
+
         super().set_data(data)
 
-    def _set_boiler_control_parameter(self):
+    def handle_frame(self, frame: Frame, writer: FrameWriter) -> None:
+        """Handles received frame.
+
+        Keyword arguments:
+            frame -- received frame
+            writer -- instance of frame writer
+        """
+        if isinstance(frame, (messages.RegData, responses.Password)):
+            self.set_data(frame.data)
+
+        elif isinstance(frame, responses.BoilerParameters):
+            self.set_parameters(frame.data)
+
+        elif isinstance(frame, messages.CurrentData):
+            self.mixers.set_data(frame.data[DATA_MIXERS])
+
+        elif isinstance(frame, responses.MixerParameters):
+            self.mixers.set_parameters(frame.data[DATA_MIXERS])
+
+        super().handle_frame(frame, writer)
+
+    def _set_data_from_regdata(self, regdata: bytes) -> None:
+        """Extracts data from regdata message.
+
+        Keyword arguments:
+            regdata -- regdata message
+        """
+        offset = 0
+        boolean_index = 0
+        for param in self.data[DATA_SCHEMA]:
+            param_id, param_type = param
+            if not isinstance(param_type, Boolean) and boolean_index > 0:
+                offset += 1
+                boolean_index = 0
+
+            param_type.unpack(regdata[offset:])
+            if isinstance(param_type, Boolean):
+                boolean_index = param_type.index(boolean_index)
+
+            self._data[param_id] = param_type.value
+            offset += param_type.size
+
+    def _set_boiler_control_parameter(self) -> None:
         """Sets boiler control parameter from device data."""
-        if (
-            device_parameters.PARAMETER_BOILER_CONTROL in self._parameters
-            and isinstance(
-                self._parameters[device_parameters.PARAMETER_BOILER_CONTROL], Parameter
-            )
+        if PARAMETER_BOILER_CONTROL in self._parameters and isinstance(
+            self._parameters[PARAMETER_BOILER_CONTROL], Parameter
         ):
-            self._parameters[device_parameters.PARAMETER_BOILER_CONTROL].value = int(
-                self.is_on
-            )
+            self._parameters[PARAMETER_BOILER_CONTROL].value = int(self.is_on)
         else:
-            self._parameters[device_parameters.PARAMETER_BOILER_CONTROL] = Parameter(
-                name=device_parameters.PARAMETER_BOILER_CONTROL,
+            self._parameters[PARAMETER_BOILER_CONTROL] = Parameter(
+                name=PARAMETER_BOILER_CONTROL,
                 value=int(self.is_on),
                 min_value=0,
                 max_value=1,
@@ -252,6 +285,14 @@ class EcoMAX(Device):
         self._fuel_burned += (fuel_consumption / 3600) * seconds_passed
         self._fuel_burned_timestamp = current_timestamp
 
+    @property
+    def password(self) -> Optional[str]:
+        """Returns device service password."""
+        if DATA_PASSWORD in self._data:
+            return self._data[DATA_PASSWORD]
+
+        return None
+
     @property
     def fuel_burned(self) -> float:
         """Returns amount of fuel burned and resets counter."""
@@ -269,11 +310,18 @@ class EcoMAX(Device):
             requests.MixerParameters,
         )
 
+    @property
+    def changes(self) -> List[Request]:
+        """Returns changed device parameters."""
+        changes = super().changes
+        changes.extend(self.mixers.queue)
+        return changes
+
     @property
     def editable_parameters(self) -> List[str]:
         """Returns list of editable parameters."""
         parameters = super().editable_parameters
-        parameters.append(device_parameters.PARAMETER_BOILER_CONTROL)
+        parameters.append(PARAMETER_BOILER_CONTROL)
         return parameters
 
 
@@ -286,6 +334,11 @@ class EcoSTER(Device):
 
     address = ECOSTER_ADDRESS
 
+    @property
+    def required_frames(self) -> Iterable[Type[Request]]:
+        """Returns list of required frames."""
+        return []
+
 
 class DeviceCollection:
     """Collection of devices.
