@@ -3,11 +3,11 @@
 from __future__ import annotations
 
 import inspect
+from types import ModuleType
 from typing import Dict, Type
 
-from . import requests, responses
 from .exceptions import FrameTypeError
-from .frame import Frame
+from .frames import Frame, messages, requests, responses
 from .helpers.singleton import Singleton
 
 
@@ -19,20 +19,31 @@ class FrameFactory(Singleton):
     """
 
     def __init__(self) -> None:
-        """Calls method to make type list."""
+        """Initializes frame factory."""
         self._types: Dict[int, Type[Frame]] = {}
 
-    def get_frame(self, type_: int, **kwargs) -> Frame:
+    def get_frame(self, frame_type: int, **kwargs) -> Frame:
         """Gets frame by frame type.
 
         Keyword arguments:
             type -- integer that represents frame type
             kwargs -- keywords arguments to pass to the frame class
         """
-        if type_ in self.types:
-            return self.types[type_](**kwargs)
+        if frame_type in self.types:
+            return self.types[frame_type](**kwargs)
 
-        raise FrameTypeError(f"Unknown frame type: {type_}.")
+        raise FrameTypeError(f"Unknown frame type: {frame_type}.")
+
+    def _load_types_from_module(self, module: ModuleType) -> None:
+        """Loads types from the module.
+
+        Keyword arguments:
+            module - a module to load types from
+        """
+        for _, cls in inspect.getmembers(module, inspect.isclass):
+            if cls.__module__ == module.__name__ and issubclass(cls, Frame):
+                # Class is within the module.
+                self._types[cls.frame_type] = cls
 
     @property
     def types(self) -> Dict[int, Type[Frame]]:
@@ -40,10 +51,7 @@ class FrameFactory(Singleton):
         types and handlers.
         """
         if not self._types:
-            for module in [requests, responses]:
-                for _, obj in inspect.getmembers(module, inspect.isclass):
-                    if obj.__module__ == module.__name__:
-                        # Object is within the module.
-                        self._types[obj.type_] = obj
+            for module in (requests, responses, messages):
+                self._load_types_from_module(module)
 
         return self._types
