@@ -7,9 +7,10 @@ from asyncio import StreamReader, StreamWriter
 from typing import Final, List, Optional
 
 from . import util
+from .constants import BROADCAST_ADDRESS, ECONET_ADDRESS
 from .exceptions import ChecksumError, LengthError
 from .factory import FrameFactory
-from .frame import BROADCAST_ADDRESS, ECONET_ADDRESS, HEADER_SIZE, Frame, Request
+from .frames import HEADER_SIZE, Frame, Request
 
 READER_BUFFER_SIZE: Final = 1000
 READER_TIMEOUT: Final = 5
@@ -48,10 +49,6 @@ class FrameWriter:
             if isinstance(frame, Frame) and not self.has(frame):
                 self._queue.append(frame)
 
-    def is_empty(self) -> bool:
-        """Checks if write queue is empty."""
-        return bool(self._queue)
-
     def has(self, request: Request) -> bool:
         """Checks if write queue contains specific request.
 
@@ -59,7 +56,7 @@ class FrameWriter:
             request - request to look for
         """
         for frame in self._queue:
-            if frame.type_ == request.type_:
+            if frame.frame_type == request.frame_type:
                 return True
 
         return False
@@ -92,6 +89,11 @@ class FrameWriter:
         self.writer.close()
         await asyncio.wait_for(self.writer.wait_closed(), timeout=WRITER_TIMEOUT)
 
+    @property
+    def is_empty(self) -> bool:
+        """Checks if write queue is empty."""
+        return not self._queue
+
 
 class FrameReader:
     """Used to read and parse received frames
@@ -142,7 +144,7 @@ class FrameReader:
                     raise ChecksumError("Incorrect frame checksum.")
 
                 return FrameFactory().get_frame(
-                    type_=payload[0],
+                    frame_type=payload[0],
                     recipient=recipient,
                     message=payload[1:-2],
                     sender=sender,
