@@ -1,12 +1,12 @@
 """Contains alarms structure parser."""
 
-from typing import Any, Dict, Tuple
+from typing import Any, Dict, Final, Optional, Tuple
 
-from pyplumio.constants import DATA_ALARMS
+ALARMS: Final = "alarms"
 
 
 def from_bytes(
-    message: bytearray, offset: int = 0, data: Dict[str, Any] = None
+    message: bytearray, offset: int = 0, data: Optional[Dict[str, Any]] = None
 ) -> Tuple[Dict, int]:
     """Parses frame message into usable data.
 
@@ -23,6 +23,6 @@ def from_bytes(
         alarms.append(message[offset + i])
 
     offset += alarms_number + 1
-    data[DATA_ALARMS] = alarms
+    data[ALARMS] = alarms
 
     return data, offset
