@@ -47,7 +47,7 @@ def unpack_ushort(data: bytes) -> int:
 
 def unpack_parameter(
     data: bytearray, offset: int, size: int = 1
-) -> Optional[Tuple[int, int, int]]:
+) -> Optional[Tuple[int, ...]]:
     """Unpacks parameter.
 
     Keyword arguments:
@@ -60,10 +60,10 @@ def unpack_parameter(
         return None
 
     value = unpack_ushort(data[offset : offset + size])
-    min_ = unpack_ushort(data[offset + size : offset + 2 * size])
-    max_ = unpack_ushort(data[offset + 2 * size : offset + 3 * size])
+    min_value = unpack_ushort(data[offset + size : offset + 2 * size])
+    max_value = unpack_ushort(data[offset + 2 * size : offset + 3 * size])
 
-    return value, min_, max_
+    return value, min_value, max_value
 
 
 def ip4_to_bytes(address: str) -> bytes:
@@ -102,24 +102,6 @@ def ip6_from_bytes(data: bytes) -> str:
     return socket.inet_ntop(socket.AF_INET6, data)
 
 
-def merge(defaults: Dict[str, Any], options: Dict[str, Any]) -> Dict[str, Any]:
-    """Merges two dictionary with options overriding defaults.
-
-    Keyword arguments:
-        defaults -- dictionary of defaults
-        options -- dictionary containing options for overriding defaults
-    """
-    if not options:
-        # Options is empty.
-        return defaults
-
-    for key in defaults.keys():
-        if key not in options:
-            options[key] = defaults[key]
-
-    return options
-
-
 def check_parameter(data: bytearray) -> bool:
     """Checks if parameter contains any bytes besides 0xFF.
 
@@ -133,39 +115,6 @@ def check_parameter(data: bytearray) -> bool:
     return False
 
 
-def uid_stamp(message: str) -> str:
-    """Calculates UID stamp.
-
-    Keyword arguments:
-        message -- uid message
-    """
-    crc_ = 0xA3A3
-    for byte in message:
-        int_ = ord(byte)
-        crc_ = crc_ ^ int_
-        for _ in range(8):
-            crc_ = (crc_ >> 1) ^ 0xA001 if crc_ & 1 else crc_ >> 1
-
-    return chr(crc_ % 256) + chr((crc_ // 256) % 256)
-
-
-def uid_5bits_to_char(number: int) -> str:
-    """Converts 5 bits from UID to ASCII character.
-
-    Keyword arguments:
-        number -- byte for conversion
-    """
-    if number < 0 or number >= 32:
-        return "#"
-
-    if number < 10:
-        return chr(ord("0") + number)
-
-    char = chr(ord("A") + number - 10)
-
-    return "Z" if char == "O" else char
-
-
 def make_list(data: Dict[Any, Any], include_keys: bool = True) -> str:
     """Converts dictionary to string.
 
